@@ -1,14 +1,17 @@
 package Taskwarrior::Kusarigama::Task;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: per-task Taskwarrior::Kusarigama::Wrapper
-$Taskwarrior::Kusarigama::Task::VERSION = '0.5.0';
+$Taskwarrior::Kusarigama::Task::VERSION = '0.6.0';
 use strict;
 
 use experimental 'postderef';
 
+use Clone;
+
 
 sub new {
     my $class = shift;
+    $class = ref $class if ref $class;
 
     my $data = pop;
 
@@ -17,6 +20,53 @@ sub new {
     bless $data, $class;
 }
 
+sub add_note {
+    my ( $self, $note ) = @_;
+
+    $self->{annotations} ||= [];
+
+    require DateTime::Functions;
+    my $now = DateTime::Functions::now();
+
+    my $timestamp = $now->ymd("") . 'T' . $now->hms("") . "Z";
+
+    push $self->{annotations}->@*, {
+        entry => $timestamp,
+        description => $note,
+    };
+}
+
+
+sub clone {
+    my $self = shift;
+
+    my $cloned = Clone::clone($self);
+
+    delete $cloned->{$_} for qw/ id uuid entry modified urgency status /;
+
+    return $self->new( $self->{_wrapper}, $cloned );
+}
+
+sub save {
+    my $self = shift;
+    
+    require Path::Tiny;
+    require JSON;
+    my $file = Path::Tiny->tempfile;
+    require List::Util;
+
+    $file->spew( JSON::to_json( [ { List::Util::pairgrep( sub { $a !~ /^_/ }, %$self ) } ] ) );
+
+    $self->{_wrapper}->RUN('import', "".$file );
+
+    my ( $new ) = $self->{_wrapper}->export('+LATEST');
+
+    delete $self->{$_} for keys %$self;
+    $self->{$_} = $new->{$_} for keys %$new;
+
+    return  $self;
+}
+
 
 sub AUTOLOAD {
     my $self = shift;
@@ -54,7 +104,7 @@ Taskwarrior::Kusarigama::Task - per-task Taskwarrior::Kusarigama::Wrapper
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
@@ -94,13 +144,18 @@ be passed via a C<_wrapper> attribute.
         { _wrapper => $wrapper, %data } 
     );
 
+=head2 clone
+
+Clone the current task. All attributes are copied, except for
+C<id>, C<uuid>, C<urgency>, C<status>, C<entry> and C<modified>.
+
 =head1 AUTHOR
 
 Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Yanick Champoux.
+This software is copyright (c) 2018, 2017 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
